@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna.php,v 1.17 2005/01/14 05:15:37 fujimoto Exp $
+ *	@version	$Id: Ethna.php,v 1.25 2005/12/01 06:04:39 fujimoto Exp $
  */
 
 /** Ethna¸饤֥: PEAR, PEAR_Error */
@@ -18,9 +18,27 @@ include_once('DB.php');
 /** Ethna¸饤֥: Smarty */
 include_once('Smarty/Smarty.class.php');
 
+if (!defined('PATH_SEPARATOR')) {
+	if (OS_WINDOWS) {
+		/** include_pathѥ졼(Windows) */
+		define('PATH_SEPARATOR', ';');
+	} else {
+		/** include_pathѥ졼(Unix) */
+		define('PATH_SEPARATOR', ':');
+	}
+}
+if (!defined('DIRECTORY_SEPARATOR')) {
+	if (OS_WINDOWS) {
+		/** ǥ쥯ȥꥻѥ졼(Windows) */
+		define('DIRECTORY_SEPARATOR', '\\');
+	} else {
+		/** ǥ쥯ȥꥻѥ졼(Unix) */
+		define('DIRECTORY_SEPARATOR', '/');
+	}
+}
 
 /** С */
-define('ETHNA_VERSION', '0.1.4');
+define('ETHNA_VERSION', '0.2.0-dev');
 
 /** Ethna١ǥ쥯ȥ */
 define('ETHNA_BASE', dirname(__FILE__));
@@ -37,11 +55,13 @@ include_once(ETHNA_BASE . '/class/Ethna_Config.php');
 include_once(ETHNA_BASE . '/class/Ethna_Controller.php');
 include_once(ETHNA_BASE . '/class/Ethna_ClassFactory.php');
 include_once(ETHNA_BASE . '/class/Ethna_DB.php');
+include_once(ETHNA_BASE . '/class/DB/Ethna_DB_PEAR.php');
 include_once(ETHNA_BASE . '/class/Ethna_Filter.php');
 include_once(ETHNA_BASE . '/class/Ethna_I18N.php');
 include_once(ETHNA_BASE . '/class/Ethna_LogWriter.php');
-include_once(ETHNA_BASE . '/class/Ethna_LogWriter_File.php');
-include_once(ETHNA_BASE . '/class/Ethna_LogWriter_Syslog.php');
+include_once(ETHNA_BASE . '/class/LogWriter/Ethna_LogWriter_Echo.php');
+include_once(ETHNA_BASE . '/class/LogWriter/Ethna_LogWriter_File.php');
+include_once(ETHNA_BASE . '/class/LogWriter/Ethna_LogWriter_Syslog.php');
 include_once(ETHNA_BASE . '/class/Ethna_Logger.php');
 include_once(ETHNA_BASE . '/class/Ethna_MailSender.php');
 include_once(ETHNA_BASE . '/class/Ethna_Session.php');
@@ -54,7 +74,7 @@ include_once(ETHNA_BASE . '/class/CLI/Ethna_CLI_ActionClass.php');
 include_once(ETHNA_BASE . '/class/View/Ethna_View_List.php');
 
 if (extension_loaded('soap')) {
-	include_once(ETHNA_BASE . '/class/SOAP/Ethna_SOAP_ActoinForm.php');
+	include_once(ETHNA_BASE . '/class/SOAP/Ethna_SOAP_ActionForm.php');
 	include_once(ETHNA_BASE . '/class/SOAP/Ethna_SOAP_Gateway.php');
 	include_once(ETHNA_BASE . '/class/SOAP/Ethna_SOAP_GatewayGenerator.php');
 	include_once(ETHNA_BASE . '/class/SOAP/Ethna_SOAP_Util.php');
