@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_AMF_ActionClass.php,v 1.2 2004/12/13 15:08:38 fujimoto Exp $
+ *	@version	$Id: Ethna_AMF_ActionClass.php,v 1.3 2005/01/06 17:44:23 fujimoto Exp $
  */
 
 // {{{ Ethna_AMF_ActionClass
@@ -23,39 +23,25 @@ class Ethna_AMF_ActionClass
 	 *	@access	private
 	 */
 
-	/**
-	 *	@var	object	Ethna_Backend		backend֥
-	 */
+	/**	@var	object	Ethna_Backend		backend֥ */
 	var $backend;
 
-	/**
-	 *	@var	object	Ethna_Config		ꥪ֥	
-	 */
+	/**	@var	object	Ethna_Config		ꥪ֥	*/
 	var $config;
 
-	/**
-	 *	@var	object	Ethna_I18N			i18n֥
-	 */
+	/**	@var	object	Ethna_I18N			i18n֥ */
 	var $i18n;
 
-	/**
-	 *	@var	object	Ethna_ActionError	󥨥顼֥
-	 */
+	/**	@var	object	Ethna_ActionError	󥨥顼֥ */
 	var $action_error;
 
-	/**
-	 *	@var	object	Ethna_ActionError	󥨥顼֥(ά)
-	 */
+	/**	@var	object	Ethna_ActionError	󥨥顼֥(ά) */
 	var $ae;
 
-	/**
-	 *	@var	object	Ethna_Session		å󥪥֥
-	 */
+	/**	@var	object	Ethna_Session		å󥪥֥ */
 	var $session;
 
-	/**
-	 *	@var	array	᥽å
-	 */
+	/**	@var	array	᥽å */
 	var $method;
 
 	/**#@-*/
