@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_ActionForm.php,v 1.13 2005/01/06 17:44:23 fujimoto Exp $
+ *	@version	$Id: Ethna_ActionForm.php,v 1.24 2006/01/29 14:39:58 halt1983 Exp $
  */
 
 /** 귿ե륿: Ⱦ */
@@ -30,6 +30,9 @@ class Ethna_ActionForm
 	 *	@access	private
 	 */
 
+	/**	@var	array	ե(ǥե) */
+	var $form_template = array();
+
 	/**	@var	array	ե */
 	var $form = array();
 
@@ -59,6 +62,9 @@ class Ethna_ActionForm
 	/**	@var	array	ե */
 	var $def = array('name', 'required', 'max', 'min', 'regexp', 'custom', 'filter', 'form_type', 'type');
 
+	/**	@var	bool	ɲøڶե饰 */
+	var	$force_validate_plus = false;
+
 	/**#@-*/
 
 	/**
@@ -78,36 +84,14 @@ class Ethna_ActionForm
 			return;
 		}
 
-		if (strcasecmp($_SERVER['REQUEST_METHOD'], 'post') == 0) {
-			$http_vars =& $_POST;
-		} else {
-			$http_vars =& $_GET;
-		}
+		// եͥƥץ졼Ȥι
+		$this->form_template = $this->_setFormTemplate($this->form_template);
 
 		// ե
-		foreach ($this->form as $name => $value) {
-			// ά
-			foreach ($this->def as $k) {
-				if (isset($value[$k]) == false) {
-					$this->form[$name][$k] = null;
-				}
-			}
+		$this->_setFormDef();
 
-			$type = to_array($value['type']);
-			if ($type[0] == VAR_TYPE_FILE) {
-				@$this->form_vars[$name] =& $_FILES[$name];
-			} else {
-				if (isset($http_vars[$name]) == false) {
-					if (isset($http_vars["{$name}_x"])) {
-						@$this->form_vars[$name] = $http_vars["{$name}_x"];
-					} else {
-						@$this->form_vars[$name] = null;
-					}
-				} else {
-					@$this->form_vars[$name] = $http_vars[$name];
-				}
-			}
-		}
+		// եͤ
+		$this->setFormVars();
 	}
 
 	/**
@@ -165,6 +149,48 @@ class Ethna_ActionForm
 		return $this->i18n->get($name);
 	}
 
+	/**
+	 *	桼줿եͤե˽äƥݡȤ
+	 *
+	 *	@access	public
+	 */
+	function setFormVars()
+	{
+		if (strcasecmp($_SERVER['REQUEST_METHOD'], 'post') == 0) {
+			$http_vars =& $_POST;
+		} else {
+			$http_vars =& $_GET;
+		}
+
+		foreach ($this->form as $name => $value) {
+			// ά
+			foreach ($this->def as $k) {
+				if (isset($value[$k]) == false) {
+					$this->form[$name][$k] = null;
+				}
+			}
+
+			$type = to_array($value['type']);
+			if ($type[0] == VAR_TYPE_FILE) {
+				if (isset($_FILES[$name]) == false) {
+					$this->form_vars[$name] = null;
+				} else {
+					$this->form_vars[$name] = $_FILES[$name];
+				}
+			} else {
+				if (isset($http_vars[$name]) == false) {
+					if (isset($http_vars["{$name}_x"])) {
+						@$this->form_vars[$name] = $http_vars["{$name}_x"];
+					} else {
+						@$this->form_vars[$name] = null;
+					}
+				} else {
+					$this->form_vars[$name] = $http_vars[$name];
+				}
+			}
+		}
+	}
+
 	/**
 	 *	եͤؤΥ(W)
 	 *
@@ -177,6 +203,23 @@ class Ethna_ActionForm
 		$this->form_vars[$name] = $value;
 	}
 
+	/**
+	 *	եꤹ
+	 *
+	 *	@access	public
+	 *	@param	string	$name	ꤹե̾(ά:nullʤƤꤹ)
+	 *	@param	array	$value	ꤹե
+	 *	@return	array	ե
+	 */
+	function setDef($name, $value)
+	{
+		if (is_null($name)) {
+			$this->form = $value;
+		}
+
+		$this->form[$name] = $value;
+	}
+
 	/**
 	 *	եͤˤ֤
 	 *
@@ -294,11 +337,33 @@ class Ethna_ActionForm
 				$retval[$name] = array();
 				$this->_getArray($vars[$name], $retval[$name], $escape);
 			} else {
-				$retval[$name] = $escape ? htmlspecialchars($vars[$name]) : $vars[$name];
+				$retval[$name] = $escape ? htmlspecialchars($vars[$name], ENT_QUOTES) : $vars[$name];
 			}
 		}
 	}
 
+	/**
+	 *	ɲøڶե饰
+	 *
+	 *	@access	public
+	 *	@return	bool	true:ɲøڶ(̾︡ڤǥ顼ȯǤ_validatePlus()ƤӽФ) false:ɲø
+	 */
+	function isForceValidatePlus()
+	{
+		return $this->force_validate_plus;
+	}
+
+	/**
+	 *	ɲøڶե饰ꤹ
+	 *
+	 *	@access	public
+	 *	@param	$force_validate_plus	ɲøڶե饰
+	 */
+	function setForceValidatePlus($force_validate_plus)
+	{
+		$this->force_validate_plus = $force_validate_plus;
+	}
+
 	/**
 	 *	ե͸ڥ᥽å
 	 *
@@ -350,7 +415,7 @@ class Ethna_ActionForm
 					}
 					// ᥽åɤμ¹
 					if ($value['custom'] != null) {
-						$this->{$value['custom']}($name);
+						$this->_validateCustom($value['custom'], $name);
 					}
 				} else {
 					if (is_array($value['type'])) {
@@ -378,7 +443,7 @@ class Ethna_ActionForm
 					}
 					// ᥽åɤμ¹
 					if ($value['custom'] != null) {
-						$this->{$value['custom']}($name);
+						$this->_validateCustom($value['custom'], $name);
 					}
 				} else {
 					if (is_array($value['type'])) {
@@ -399,7 +464,7 @@ class Ethna_ActionForm
 			}
 		}
 
-		if ($this->ae->count() == 0) {
+		if ($this->ae->count() == 0 || $this->isForceValidatePlus()) {
 			// ɲøڥ᥽å
 			$this->_validatePlus();
 		}
@@ -450,7 +515,7 @@ class Ethna_ActionForm
 				$i += 2;
 			} else if ($c == 0xad || ($c >= 0xf9 && $c <= 0xfc)) {
 				/* IBMĥʸ / NECIBMĥʸ */
-				return $this->ad->add(E_FORM_INVALIDCHAR, $name, '{form}˵¸ʸϤƤޤ');
+				return $this->ae->add($name, '{form}˵¸ʸϤƤޤ', E_FORM_INVALIDCHAR);
 			} else {
 				$i++;
 			}
@@ -564,7 +629,7 @@ class Ethna_ActionForm
 					$form_name = $key;
 				}
 				$hidden_vars .= sprintf("<input type=\"hidden\" name=\"%s\" value=\"%s\" />\n",
-					$form_name, htmlspecialchars($v));
+					$form_name, htmlspecialchars($v, ENT_QUOTES));
 			}
 		}
 		return $hidden_vars;
@@ -580,6 +645,33 @@ class Ethna_ActionForm
 	function handleError($name, $code)
 	{
 		$def = $this->getDef($name);
+
+		// 桼顼å
+		$code_map = array(
+			E_FORM_REQUIRED		=> 'required_error',
+			E_FORM_WRONGTYPE_SCALAR	=> 'type_error',
+			E_FORM_WRONGTYPE_ARRAY	=> 'type_error',
+			E_FORM_WRONGTYPE_INT	=> 'type_error',
+			E_FORM_WRONGTYPE_FLOAT	=> 'type_error',
+			E_FORM_WRONGTYPE_DATETIME	=> 'type_error',
+			E_FORM_WRONGTYPE_BOOLEAN	=> 'type_error',
+			E_FORM_MIN_INT		=> 'min_error',
+			E_FORM_MIN_FLOAT	=> 'min_error',
+			E_FORM_MIN_DATETIME	=> 'min_error',
+			E_FORM_MIN_FILE		=> 'min_error',
+			E_FORM_MIN_STRING	=> 'min_error',
+			E_FORM_MAX_INT		=> 'max_error',
+			E_FORM_MAX_FLOAT	=> 'max_error',
+			E_FORM_MAX_DATETIME	=> 'max_error',
+			E_FORM_MAX_FILE		=> 'max_error',
+			E_FORM_MAX_STRING	=> 'max_error',
+			E_FORM_REGEXP		=> 'regexp_error',
+		);
+		if (array_key_exists($code_map[$code], $def)) {
+			$this->ae->add($name, $def[$code_map[$code]], $code);
+			return;
+		}
+
 		if ($code == E_FORM_REQUIRED) {
 			switch ($def['form_type']) {
 			case FORM_TYPE_TEXT:
@@ -623,7 +715,7 @@ class Ethna_ActionForm
 			$this->ae->add($name, "{form}ˤ%dKBʾΥեꤷƲ", $code, $def['min']);
 			return;
 		} else if ($code == E_FORM_MIN_STRING) {
-			$this->ae->add($name, "{form}ˤ%dʸʾϤƲ", $code, $def['min']);
+			$this->ae->add($name, "{form}ˤ%dʸʾ(Ⱦ%dʸʾ)ϤƲ", $code, intval($def['min']/2), $def['min']);
 			return;
 		} else if ($code == E_FORM_MAX_INT) {
 			$this->ae->add($name, "{form}ˤ%dʲο()ϤƲ", $code, $def['max']);
@@ -638,7 +730,7 @@ class Ethna_ActionForm
 			$this->ae->add($name, "{form}ˤ%dKBʲΥեꤷƲ", $code, $def['max']);
 			return;
 		} else if ($code == E_FORM_MAX_STRING) {
-			$this->ae->add($name, "{form}%dʸʲϤƲ", $code, $def['max']);
+			$this->ae->add($name, "{form}%dʸʲ(Ⱦ%dʸʲ)ϤƲ", $code, intval($def['max']/2), $def['max']);
 			return;
 		} else if ($code == E_FORM_REGEXP) {
 			$message = "{form}ϤƤ";
@@ -823,7 +915,7 @@ class Ethna_ActionForm
 		// custom (TODO: respect $test flag)
 		if ($def['custom'] != null) {
 			if (isset($this->form[$name]['type']) && is_array($this->form[$name]['type']) == false) {
-				$this->{$def['custom']}($name);
+				$this->_validateCustom($def['custom'], $name);
 			} else {
 				// ξǰǥ᥽åɤ¹Ԥ뤿᥹å
 			}
@@ -832,6 +924,24 @@ class Ethna_ActionForm
 		return true;
 	}
 
+	/**
+	 *	å᥽åɤ¹Ԥ
+	 *
+	 *	@access	protected
+	 *	@param	string	$method_list	᥽å̾(޶ڤ)
+	 *	@param	string	$name			ե̾
+	 */
+	function _validateCustom($method_list, $name)
+	{
+		$method_list = preg_split('/\s*,\s*/', $method_list, -1, PREG_SPLIT_NO_EMPTY);
+		if (is_array($method_list) == false) {
+			return;
+		}
+		foreach ($method_list as $method) {
+			$this->$method($name);
+		}
+	}
+
 	/**
 	 *	եͤѴե륿ŬѤ
 	 *
@@ -929,6 +1039,36 @@ class Ethna_ActionForm
 	{
 		return mb_convert_kana($value, "K");
 	}
+
+	/**
+	 *	եƥץ졼Ȥꤹ
+	 *
+	 *	@access	protected
+	 *	@param	array	$form_template	եͥƥץ졼
+	 *	@return	array	եͥƥץ졼
+	 */
+	function _setFormTemplate($form_template)
+	{
+		return $form_template;
+	}
+
+	/**
+	 *	եꤹ
+	 *
+	 *	@access	protected
+	 */
+	function _setFormDef()
+	{
+		foreach ($this->form as $key => $value) {
+			if (array_key_exists($key, $this->form_template) && is_array($this->form_template)) {
+				foreach ($this->form_template[$key] as $def_key => $def_value) {
+					if (array_key_exists($def_key, $value) == false) {
+						$this->form[$key][$def_key] = $def_value;
+					}
+				}
+			}
+		}
+	}
 }
 // }}}
 ?>
