@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_Controller.php,v 1.27 2005/01/06 17:44:23 fujimoto Exp $
+ *	@version	$Id: Ethna_Controller.php,v 1.38 2006/01/16 15:48:34 halt1983 Exp $
  */
 
 // {{{ Ethna_Controller
@@ -136,6 +136,9 @@ class Ethna_Controller
 	/**	@var	object	Ethna_Logger		֥ */
 	var	$logger = null;
 
+	/**	@var	bool	CLI¹ե饰 */
+	var	$cli 	= false;
+
 	/**#@-*/
 
 
@@ -147,7 +150,9 @@ class Ethna_Controller
 	function Ethna_Controller()
 	{
 		$GLOBALS['controller'] =& $this;
-		$this->base = BASE;
+		if ($this->base == "") {
+			$this->base = BASE;
+		}
 
 		// 饹եȥꥪ֥Ȥ
 		$class_factory = $this->class['class'];
@@ -339,7 +344,7 @@ class Ethna_Controller
 	 *	@param	string	$key	DB("r", ...)
 	 *	@return	string	$keyбDB(̵꤬null)
 	 */
-	function getDB($key)
+	function getDBType($key)
 	{
 		if (isset($this->db[$key]) == false) {
 			return null;
@@ -517,6 +522,28 @@ class Ethna_Controller
 		$this->client_type = $client_type;
 	}
 
+	/**
+	 *	CLI¹ե饰
+	 *
+	 *	@access	public
+	 *	@return	bool	CLI¹ե饰
+	 */
+	function getCLI()
+	{
+		return $this->cli;
+	}
+
+	/**
+	 *	CLI¹ե饰ꤹ
+	 *
+	 *	@access	public
+	 *	@param	bool	CLI¹ե饰
+	 */
+	function setCLI($cli)
+	{
+		$this->cli = $cli;
+	}
+
 	/**
 	 *	ץꥱΥȥݥ
 	 *
@@ -538,13 +565,15 @@ class Ethna_Controller
 	 *	@access	public
 	 *	@param	string	$class_name		ץꥱ󥳥ȥΥ饹̾
 	 *	@param	string	$action_name	¹Ԥ륢̾
+	 *	@param	bool	$enable_filter	ե륿ͭˤ뤫ɤ
 	 *	@static
 	 */
-	function main_CLI($class_name, $action_name)
+	function main_CLI($class_name, $action_name, $enable_filter = true)
 	{
 		$c =& new $class_name;
+		$c->setCLI(true);
 		$c->action[$action_name] = array();
-		$c->trigger('www', $action_name);
+		$c->trigger('www', $action_name, "", $enable_filter);
 	}
 
 	/**
@@ -582,16 +611,22 @@ class Ethna_Controller
 	 *	@param	strint	$type					(WWW/SOAP/AMF)
 	 *	@param	mixed	$default_action_name	Υ̾
 	 *	@param	mixed	$fallback_action_name	̾Ǥʤä˼¹Ԥ륢̾
+	 *	@param	bool	$enable_filter	ե륿ͭˤ뤫ɤ
 	 *	@return	mixed	0:ｪλ Ethna_Error:顼
 	 */
-	function trigger($type, $default_action_name = "", $fallback_action_name = "")
+	function trigger($type, $default_action_name = "", $fallback_action_name = "", $enable_filter = true)
 	{
 		// ե륿
-		$this->_createFilterChain();
+		if ($enable_filter) {
+			$this->_createFilterChain();
+		}
 
 		// ¹ե륿
 		for ($i = 0; $i < count($this->filter_chain); $i++) {
-			$this->filter_chain[$i]->preFilter();
+			$r = $this->filter_chain[$i]->preFilter();
+			if (Ethna::isError($r)) {
+				return $r;
+			}
 		}
 
 		// trigger
@@ -604,8 +639,13 @@ class Ethna_Controller
 		}
 
 		// ¹Ըե륿
-		for ($i = count($this->filter_chain) - 1; $i >= 0; $i--) {
-			$this->filter_chain[$i]->postFilter();
+		if ($this->getCLI() == false) {
+			for ($i = count($this->filter_chain) - 1; $i >= 0; $i--) {
+				$r = $this->filter_chain[$i]->postFilter();
+				if (Ethna::isError($r)) {
+					return $r;
+				}
+			}
 		}
 	}
 
@@ -613,8 +653,8 @@ class Ethna_Controller
 	 *	ե졼ν¹Ԥ(WWW)
 	 *
 	 *	$default_action_name󤬻ꤵ줿硢ǻꤵ줿
-	 *	ʳϼդʤ(ʳΥ󤬻ꤵ줿硢
-	 *	Ƭǻꤵ줿󤬼¹Ԥ)
+	 *	ʳϼդʤ(ꤵƤʤ󤬻ꤵ줿
+	 *	硢Ƭǻꤵ줿󤬼¹Ԥ)
 	 *
 	 *	@access	private
 	 *	@param	mixed	$default_action_name	Υ̾
@@ -633,8 +673,8 @@ class Ethna_Controller
 				$this->logger->log(LOG_DEBUG, 'undefined action [%s] -> try fallback action [%s]', $action_name, $fallback_action_name);
 				$action_obj =& $this->_getAction($fallback_action_name);
 			}
-			if ($action_obj == null) {
-				return Ethna::raiseError(E_APP_UNDEFINED_ACTION, "undefined action [%s]", $action_name);
+			if (is_null($action_obj)) {
+				return Ethna::raiseError("undefined action [%s]", E_APP_UNDEFINED_ACTION, $action_name);
 			} else {
 				$action_name = $fallback_action_name;
 			}
@@ -659,6 +699,8 @@ class Ethna_Controller
 
 		// Хåɽ¹
 		$backend =& $this->getBackend();
+		$session =& $this->getSession();
+		$session->restore();
 		$forward_name = $backend->perform($action_name);
 
 		// ¹Ըե륿
@@ -698,11 +740,8 @@ class Ethna_Controller
 	 */
 	function _trigger_SOAP()
 	{
-		// 󥹥ץȤ򥤥󥯥롼
-		$this->_includeActionScript();
-
 		// SOAPȥꥯ饹
-		$gg =& new Ethna_SoapGatewayGenerator();
+		$gg =& new Ethna_SOAP_GatewayGenerator();
 		$script = $gg->generate();
 		eval($script);
 
@@ -756,7 +795,7 @@ class Ethna_Controller
 		// 
 		list ($log_level, $dummy) = $this->logger->errorLevelToLogLevel($error->getLevel());
 		$message = $error->getMessage();
-		$this->logger->log($log_level, sprintf("[APP(%d)] %s", $error->getCode(), $message));
+		$this->logger->log($log_level, sprintf("%s [ERROR CODE(%d)]", $message, $error->getCode()));
 	}
 
 	/**
@@ -1348,13 +1387,15 @@ class Ethna_Controller
 	 *
 	 *	@access	public
 	 *	@return	object	Smarty	ƥץ졼ȥ󥸥󥪥֥
-	 *	@todo	֥åؿץ饰(etc)б
 	 */
 	function &getTemplateEngine()
 	{
 		$smarty =& new Smarty();
 		$smarty->template_dir = $this->getTemplatedir();
-		$smarty->compile_dir = $this->getDirectory('template_c') . '/tpl_' . md5($smarty->template_dir);
+		$smarty->compile_dir = $this->getDirectory('template_c');
+		$smarty->compile_id = md5($smarty->template_dir);
+
+		// ФäƤߤ
 		if (@is_dir($smarty->compile_dir) == false) {
 			mkdir($smarty->compile_dir, 0755);
 		}
@@ -1368,6 +1409,7 @@ class Ethna_Controller
 		$smarty->register_modifier('filter', 'smarty_modifier_filter');
 		$smarty->register_modifier('unique', 'smarty_modifier_unique');
 		$smarty->register_modifier('wordwrap_i18n', 'smarty_modifier_wordwrap_i18n');
+		$smarty->register_modifier('truncate_i18n', 'smarty_modifier_truncate_i18n');
 		$smarty->register_modifier('i18n', 'smarty_modifier_i18n');
 		$smarty->register_modifier('checkbox', 'smarty_modifier_checkbox');
 		$smarty->register_modifier('select', 'smarty_modifier_select');
@@ -1668,6 +1710,10 @@ class Ethna_Controller
 	 */
 	function _selectDSN($type, $dsn_list)
 	{
+		if (is_array($dsn_list) == false) {
+			return $dsn_list;
+		}
+
 		// ǥե:
 		list($usec, $sec) = explode(' ', microtime());
 		mt_srand($sec + ((float) $usec * 100000));
