@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_Session.php,v 1.3 2005/01/06 17:44:23 fujimoto Exp $
+ *	@version	$Id: Ethna_Session.php,v 1.5 2005/07/29 13:14:52 fujimoto Exp $
  */
 
 // {{{ Ethna_Session
@@ -73,7 +73,15 @@ class Ethna_Session
 		if (array_key_exists($this->session_name, $http_vars) && $http_vars[$this->session_name] != null) {
 			$_COOKIE[$this->session_name] = $http_vars[$this->session_name];
 		}
+	}
 
+	/**
+	 *	å
+	 *
+	 *	@access	public
+	 */
+	function restore()
+	{
 		if (!empty($_COOKIE[$this->session_name]) || session_id() != null) {
 			session_start();
 			$this->session_start = true;
@@ -273,7 +281,7 @@ class Ethna_Session
 		if (($src & 0xffff0000) == ($dst & 0xffff0000)) {
 			return true;
 		} else {
-			$this->logger(LOG_NOTICE, "session IP validation failed [%s] - [%s]", $src_ip, $dst_ip);
+			$this->logger->log(LOG_NOTICE, "session IP validation failed [%s] - [%s]", $src_ip, $dst_ip);
 			return false;
 		}
 	}
